OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contatos",
    "Copy Url to clipboard" : "Copiar URL para a área de transferência",
    "Download" : "Baixar",
    "ShowURL" : "MostrarURL",
    "Share Addressbook" : "Compartilhar Livro de Endereços",
    "Delete Addressbook" : "Excluir Livro de Endereços",
    "Share with users or groups" : "Compartilhar com usuários ou grupos",
    "Delete" : "Excluir",
    "can edit" : "pode editar",
    "Address book name" : "Nome do livro de endereços",
    "Import" : "Importar",
    "The selected image is too big (max 1MB)" : "A imagem selecionada é grande demais (máximo 1MB)",
    "No contacts in here" : "Nenhum contato aqui",
    "Name" : "Nome",
    "Organization" : "Organização",
    "Title" : "Título",
    "Add field ..." : "Adicionar campo...",
    "No search result for {query}" : "Nenhum resultado de busca para {query}",
    "_%n contact_::_%n contacts_" : ["%n contato","%n contatos"],
    "Post office box" : "Caixa de correio",
    "Postal code" : "Código postal",
    "City" : "Cidade",
    "State or province" : "Estado ou província",
    "Country" : "País",
    "Address" : "Endereço",
    "(new group)" : "(novo grupo)",
    "Last name" : "Sobrenome",
    "First name" : "Primeiro nome",
    "Additional names" : "Nomes adicionais",
    "Prefix" : "Prefixo",
    "Suffix" : "Sufixo",
    "All contacts" : "Todos os contatos",
    "Not grouped" : "Não agrupado",
    "New contact" : "Novo contato",
    "{addressbook} shared by {owner}" : "{addressbook} compartilhado por {owner}",
    "Contact could not be created." : "O contato não pode ser criado.",
    "No contacts in file. Only VCard files are allowed." : "Nenhum contato em arquivo. Somente arquivos vCard são permitidos.",
    "Only VCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Somente VCard versão 4.0 (RFC6350) ou versão 3.0 (RFC2426) são suportadoas.",
    "Nickname" : "Apelido",
    "Detailed name" : "Nome detalhado",
    "Notes" : "Notas",
    "Website" : "Website",
    "Federated Cloud ID" : "ID de núvem Associada",
    "Home" : "Casa",
    "Work" : "Trabalho",
    "Other" : "Outro",
    "Groups" : "Grupos",
    "Birthday" : "Aniversário",
    "Anniversary" : "Aniversário",
    "Date of death" : "Data da morte",
    "Email" : "E-mail",
    "Instant messaging" : "Mensagem instantânea",
    "Phone" : "Telefone",
    "Mobile" : "Móvel",
    "Fax" : "Fax",
    "Fax home" : "Fax de casa",
    "Fax work" : "Fax do trabalho",
    "Pager" : "Pager",
    "Voice" : "Voz",
    "Social network" : "Rede social",
    "Settings" : "Configurações"
},
"nplurals=2; plural=(n > 1);");
